==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Input/modplug/translations/modplug_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="47"/>
        <source>ModPlug Plugin</source>
        <translation>Plugin ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="53"/>
        <source>ModPlug Files</source>
        <translation>Arquivos ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="137"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>Sobre o plugin ModPlug Audio</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="138"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Plugin Qmmp ModPlug Audio</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="139"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="140"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Baseado no Modplug Plugin for Xmms</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="141"/>
        <source>Modplug Plugin developers:</source>
        <translation>Programadores ModPlug:</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="142"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="143"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="144"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>Speed</source>
        <translation>Velocidade</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="72"/>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="73"/>
        <location filename="../modplugmetadatamodel.cpp" line="94"/>
        <source>Samples</source>
        <translation>Amostras</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="74"/>
        <location filename="../modplugmetadatamodel.cpp" line="103"/>
        <source>Instruments</source>
        <translation>Instrumentos</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="75"/>
        <source>Patterns</source>
        <translation>Padrões</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="76"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="108"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation>Preferências do plugin ModPlug</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation>Qualidade</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation>Resolução</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation>16 bit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation>8 bit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation>Estéreo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation>Mono (downmix)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation>Amostragem</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation>Nearest (mais rápida)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation>Linear (rápida)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation>Spline (boa qualidade)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>8-tap Fir (qualidade extremamente alta)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation>11025 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation>Efeitos</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation>Reverb</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="202"/>
        <location filename="../settingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation>Profundidade (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <location filename="../settingsdialog.ui" line="368"/>
        <location filename="../settingsdialog.ui" line="499"/>
        <location filename="../settingsdialog.ui" line="618"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="260"/>
        <location filename="../settingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation>Atraso (ms)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="292"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation>Amplificação de graves</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation>Valor (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation>Intervalo (Hz)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="426"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation>Surround</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="551"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation>Amplificador</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation>Definir o amplificador muito
alto pode provocar distorção!</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation>Diversos</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="677"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation>Usar nome do arquivo como nome da faixa</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation>Redução de ruído</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation>Informações rápidas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation>Reproduzir Amiga MOD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation>Ciclos</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation>Sem loop</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation>Com loop</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation>vez(es)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation>Loop infinito</translation>
    </message>
</context>
</TS>

==> qmmp-1.0.7.tar.bz2: qmmp-1.0.7/src/plugins/Input/modplug/translations/modplug_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="58"/>
        <source>ModPlug Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="64"/>
        <source>ModPlug Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="130"/>
        <source>About ModPlug Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="131"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="132"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="133"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="134"/>
        <source>Modplug Plugin developers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="135"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="136"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="137"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>File name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="142"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="147"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="148"/>
        <source>Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="149"/>
        <source>Tempo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="150"/>
        <location filename="../modplugmetadatamodel.cpp" line="171"/>
        <source>Samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="151"/>
        <location filename="../modplugmetadatamodel.cpp" line="180"/>
        <source>Instruments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="152"/>
        <source>Patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="153"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="185"/>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="202"/>
        <location filename="../settingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <location filename="../settingsdialog.ui" line="368"/>
        <location filename="../settingsdialog.ui" line="499"/>
        <location filename="../settingsdialog.ui" line="618"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="260"/>
        <location filename="../settingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="292"/>
        <source>40</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="426"/>
        <source>10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="551"/>
        <source>5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="677"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
